@@ -113,6 +113,7 @@ predict(modc, newdata=learn)[1:10]
 
 # bundling for survival
 
+while(FALSE) {
 data(GBSG2)
 rcomb <- list(list(model=coxph, predict=predict))
 
@@ -129,3 +130,4 @@ mydata <- as.data.frame(cbind(y, x))
 cv(y, y ~ ., data=mydata, model=lm, predict=predict)
 bootest(y, y ~ ., data=mydata, model=lm, predict=predict)
 bagging(y ~., data=mydata, nbagg=10)
+}
\ No newline at end of file
