@@ -41,7 +41,7 @@ cleanEx(); ..nameEx <- "DLBCL"
 ##___ Examples ___:
 
 data(DLBCL)
-survfit(Surv(time, cens), data=DLBCL)
+survfit(Surv(time, cens) ~ 1, data=DLBCL)
 
 
 ## Keywords: 'datasets'.
@@ -71,7 +71,7 @@ table(GBSG2$horTh)
 
 # pooled Kaplan-Meier
 
-mod <- survfit(Surv(time, cens), data=GBSG2)
+mod <- survfit(Surv(time, cens) ~1, data=GBSG2)
 # integrated Brier score
 sbrier(Surv(GBSG2$time, GBSG2$cens), mod)
 # Brier score at 5 years
@@ -593,7 +593,7 @@ cleanEx(); ..nameEx <- "sbrier"
 data(DLBCL)
 smod <- Surv(DLBCL$time, DLBCL$cens)
 
-KM <- survfit(smod)
+KM <- survfit(smod ~ 1)
 # integrated Brier score up to max(DLBCL$time)
 sbrier(smod, KM)
 
@@ -634,7 +634,7 @@ stopifnot(all.equal(cleans(a),0.25))
 
 n <- 100
 time <- 1:100
-mod <- survfit(Surv(time, cens))
+mod <- survfit(Surv(time, cens) ~ 1)
 a <- sbrier(Surv(time, cens), rep(list(mod), n))
 mymin <- mod$surv * (1 - mod$surv)
 stopifnot(all.equal(cleans(a),sum(mymin)/max(time)))
@@ -666,8 +666,8 @@ cens <- rep(1, length(time))
 
 # no information about the groups
 
-a <- sbrier(Surv(time, cens), survfit(Surv(time, cens)))
-b <- sbrier(Surv(time, cens), rep(list(survfit(Surv(time, cens))), 20))
+a <- sbrier(Surv(time, cens), survfit(Surv(time, cens) ~ 1))
+b <- sbrier(Surv(time, cens), rep(list(survfit(Surv(time, cens) ~ 1)), 20))
 stopifnot(all.equal(a, b))
 
 # risk groups known
